@@ -12,7 +12,7 @@ Usage::
     session_client: EBSClient = session.client("ebs")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, TYPE_CHECKING
+from typing import Any, Dict, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_ebs.type_defs import (
     GetSnapshotBlockResponseTypeDef,
@@ -25,21 +25,21 @@ __all__ = ("EBSClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    ValidationException: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
+    ValidationException: Type[Boto3ClientError]
 
 
 class EBSClient:
     """
-    [EBS.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/ebs.html#EBS.Client)
+    [EBS.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.35/reference/services/ebs.html#EBS.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/ebs.html#EBS.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.35/reference/services/ebs.html#EBS.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -50,14 +50,14 @@ class EBSClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/ebs.html#EBS.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.35/reference/services/ebs.html#EBS.Client.generate_presigned_url)
         """
 
     def get_snapshot_block(
         self, SnapshotId: str, BlockIndex: int, BlockToken: str
     ) -> GetSnapshotBlockResponseTypeDef:
         """
-        [Client.get_snapshot_block documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/ebs.html#EBS.Client.get_snapshot_block)
+        [Client.get_snapshot_block documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.35/reference/services/ebs.html#EBS.Client.get_snapshot_block)
         """
 
     def list_changed_blocks(
@@ -69,7 +69,7 @@ class EBSClient:
         StartingBlockIndex: int = None,
     ) -> ListChangedBlocksResponseTypeDef:
         """
-        [Client.list_changed_blocks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/ebs.html#EBS.Client.list_changed_blocks)
+        [Client.list_changed_blocks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.35/reference/services/ebs.html#EBS.Client.list_changed_blocks)
         """
 
     def list_snapshot_blocks(
@@ -80,5 +80,5 @@ class EBSClient:
         StartingBlockIndex: int = None,
     ) -> ListSnapshotBlocksResponseTypeDef:
         """
-        [Client.list_snapshot_blocks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
+        [Client.list_snapshot_blocks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.35/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
         """
